@@ -203,6 +203,7 @@ gnetwork_ssl_cert_get_type (void)
 GNetworkSslCert *
 gnetwork_ssl_cert_dup (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   GNetworkSslCert *retval;
 
   if (cert == NULL)
@@ -225,6 +226,9 @@ gnetwork_ssl_cert_dup (GNetworkSslCert * cert)
   retval->issued = cert->issued;
 
   return retval;
+#else
+  return NULL;
+#endif /* _USE_SSL */
 }
 
 
@@ -239,6 +243,7 @@ gnetwork_ssl_cert_dup (GNetworkSslCert * cert)
 void
 gnetwork_ssl_cert_free (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   if (cert == NULL)
     return;
 
@@ -252,6 +257,7 @@ gnetwork_ssl_cert_free (GNetworkSslCert * cert)
   g_free (cert->country);
 
   g_free (cert);
+#endif /* _USE_SSL */
 }
 
 
@@ -268,9 +274,13 @@ gnetwork_ssl_cert_free (GNetworkSslCert * cert)
 GNetworkSslCertType
 gnetwork_ssl_cert_get_cert_type (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, GNETWORK_SSL_CERT_INVALID);
 
   return cert->cert_type;
+#else
+  return GNETWORK_SSL_CERT_INVALID;
+#endif /* _USE_SSL */
 }
 
 
@@ -287,10 +297,14 @@ gnetwork_ssl_cert_get_cert_type (GNetworkSslCert * cert)
 G_CONST_RETURN gchar *
 gnetwork_ssl_cert_get_name (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, NULL);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, NULL);
 
   return cert->name;
+#else
+  return NULL;
+#endif /* _USE_SSL */
 }
 
 
@@ -308,10 +322,14 @@ gnetwork_ssl_cert_get_name (GNetworkSslCert * cert)
 G_CONST_RETURN gchar *
 gnetwork_ssl_cert_get_email (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, NULL);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, NULL);
 
   return cert->email;
+#else
+  return NULL;
+#endif /* _USE_SSL */
 }
 
 
@@ -329,10 +347,14 @@ gnetwork_ssl_cert_get_email (GNetworkSslCert * cert)
 G_CONST_RETURN gchar *
 gnetwork_ssl_cert_get_organization (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, NULL);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, NULL);
 
   return cert->organization;
+#else
+  return NULL;
+#endif /* _USE_SSL */
 }
 
 
@@ -350,10 +372,14 @@ gnetwork_ssl_cert_get_organization (GNetworkSslCert * cert)
 G_CONST_RETURN gchar *
 gnetwork_ssl_cert_get_department (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, NULL);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, NULL);
 
   return cert->department;
+#else
+  return NULL;
+#endif /* _USE_SSL */
 }
 
 
@@ -371,10 +397,14 @@ gnetwork_ssl_cert_get_department (GNetworkSslCert * cert)
 G_CONST_RETURN gchar *
 gnetwork_ssl_cert_get_city (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, NULL);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, NULL);
 
   return cert->city;
+#else
+  return NULL;
+#endif /* _USE_SSL */
 }
 
 
@@ -392,10 +422,14 @@ gnetwork_ssl_cert_get_city (GNetworkSslCert * cert)
 G_CONST_RETURN gchar *
 gnetwork_ssl_cert_get_province (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, NULL);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, NULL);
 
   return cert->province;
+#else
+  return NULL;
+#endif /* _USE_SSL */
 }
 
 
@@ -413,10 +447,14 @@ gnetwork_ssl_cert_get_province (GNetworkSslCert * cert)
 G_CONST_RETURN gchar *
 gnetwork_ssl_cert_get_country (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, NULL);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, NULL);
 
   return cert->country;
+#else
+  return NULL;
+#endif /* _USE_SSL */
 }
 
 
@@ -433,10 +471,14 @@ gnetwork_ssl_cert_get_country (GNetworkSslCert * cert)
 glong
 gnetwork_ssl_cert_get_expiration (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, -1);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, -1);
 
   return cert->expiration;
+#else
+  return -1;
+#endif /* _USE_SSL */
 }
 
 
@@ -454,10 +496,14 @@ gnetwork_ssl_cert_get_expiration (GNetworkSslCert * cert)
 glong
 gnetwork_ssl_cert_get_activation (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, -1);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, -1);
 
   return cert->activation;
+#else
+  return -1;
+#endif /* _USE_SSL */
 }
 
 
@@ -474,10 +520,14 @@ gnetwork_ssl_cert_get_activation (GNetworkSslCert * cert)
 glong
 gnetwork_ssl_cert_get_issued (GNetworkSslCert * cert)
 {
+#ifdef _USE_SSL
   g_return_val_if_fail (cert != NULL, -1);
   g_return_val_if_fail (cert->cert_type == GNETWORK_SSL_CERT_X509, -1);
 
   return cert->activation;
+#else
+  return -1;
+#endif /* _USE_SSL */
 }
 
 
@@ -539,10 +589,10 @@ gnetwork_ssl_cert_get_errors (GNetworkSslCert * certificate, GNetworkSslCertErro
 	      str = g_strdup (_("The certificate could not be parsed."));
 	      break;
 	    case GNETWORK_SSL_CERT_ERROR_EXPIRED:
+#ifdef _USE_SSL
 	      {
 		const gchar *format;
 		glong expiration, difference;
-
 		expiration = gnetwork_ssl_cert_get_expiration (certificate);
 		difference = time (NULL) - expiration;
 
@@ -596,8 +646,12 @@ gnetwork_ssl_cert_get_errors (GNetworkSslCert * certificate, GNetworkSslCertErro
 		    str = NULL;
 		  }
 	      }
+#else
+	      str = g_strdup (_("The certificate has expired"));
+#endif /* _USE_SSL */
 	      break;
 	    case GNETWORK_SSL_CERT_ERROR_NOT_ACTIVATED:
+#ifdef _USE_SSL
 	      {
 		const gchar *format;
 		glong activation, difference;
@@ -655,6 +709,9 @@ gnetwork_ssl_cert_get_errors (GNetworkSslCert * certificate, GNetworkSslCertErro
 		    str = NULL;
 		  }
 	      }
+#else
+	      str = g_strdup (_("The certificate is not usable yet."));
+#endif /* _USE_SSL */
 	      break;
 
 	    case GNETWORK_SSL_CERT_ERROR_HOSTNAME_MISMATCH:
